@@ -9,7 +9,7 @@ subroutine Dcl_2D_cont_shade( outname,  &
   &  shade_min, shade_max, x_title, y_title,  &
   &  form_typec, form_types, viewx_min, viewx_max,  &
   &  viewy_min, viewy_max, color_num, cont_num, nongrid,  &
-  &  xg, yg )
+  &  xg, yg, mono, mono_val, mono_lev )
   ! 2  2 ѿȥ顼ɤ褹.
   use dcl
   implicit none
@@ -24,8 +24,8 @@ subroutine Dcl_2D_cont_shade( outname,  &
   real, intent(in) :: shade_max  ! ɤ
   character(*), intent(in) :: x_title  ! x Υȥ
   character(*), intent(in) :: y_title  ! y Υȥ
-  character(6), intent(in), optional :: form_typec  ! contour ѤΥեޥå
-  character(6), intent(in), optional :: form_types  ! shade ѤΥեޥå
+  character(6), intent(in) :: form_typec  ! contour ѤΥեޥå
+  character(6), intent(in) :: form_types  ! shade ѤΥեޥå
   real, intent(in), optional :: viewx_min  ! ӥ塼ݡȤ x κǾ
   real, intent(in), optional :: viewx_max  ! ӥ塼ݡȤ x κ
   real, intent(in), optional :: viewy_min  ! ӥ塼ݡȤ y κǾ
@@ -45,10 +45,18 @@ subroutine Dcl_2D_cont_shade( outname,  &
                     ! Ȥǽ.
                     ! 3 ܤ, xg(:,1)  yg(:,1)  1 ܤ
                     ! ɽ褦˻ꤹ뤳.
+  logical, intent(in), optional :: mono  ! ΥȡγĴˤ [.true.]
+                                         ! ǥեȤ .false.
+  real, intent(in), optional :: mono_val(:)  ! Ĵζ.
+                    ! mono=.true. ΤȤɬꤷʤȥ顼֤.
+                    ! ͤ mono_lev + 1 ʬ¸ߤʤФʤʤ.
+  integer, intent(in), optional :: mono_lev(:)  ! ȡޥåֹ. dcl  3 
+                    ! mono=.true. ΤȤꤷʤȥ顼֤.
   integer :: i, j, k  ! ź
-  integer :: nx, ny
+  integer :: nx, ny, s_num, c_num
   real :: vx_min, vx_max, vy_min, vy_max
   real :: undef, RMISS
+  logical :: monoto
 
   nx=size(x)
   ny=size(y)
@@ -78,6 +86,38 @@ subroutine Dcl_2D_cont_shade( outname,  &
      vy_max=0.8
   end if
 
+  if(present(color_num))then
+     s_num=color_num
+  else
+     s_num=56
+  end if
+
+  if(present(cont_num))then
+     c_num=cont_num
+  else
+     c_num=10
+  end if
+
+  if(present(mono))then
+     if(present(mono_val).and.present(mono_lev))then
+        if(size(mono_val)-1==size(mono_lev))then
+           monoto=mono
+        else
+           write(*,*) "*** ERROR ***"
+           write(*,*) "[array number] : mono_val = mono_lev + 1"
+           write(*,*) "STOP"
+           stop
+        end if
+     else
+        write(*,*) "*** ERROR ***"
+        write(*,*) "When option MONO is true, MONO_VAL and MONO_LEV must be specified."
+        write(*,*) "STOP"
+        stop
+     end if
+  else
+     monoto=.false.
+  end if
+
 !-- ޤ ---
 
   call undef_CReSS2Dcl( nx, ny, 1, contour)
@@ -98,6 +138,17 @@ subroutine Dcl_2D_cont_shade( outname,  &
   call DclSetViewPort( vx_min, vx_max, vy_min, vy_max )
   call DclSetTransFunction
 
+  if(monoto==.true.)then
+     call DclSetParm('ENABLE_SOFTFILL',.true.)
+     call DclClearShadeLevel
+     call DclSetShadeLevel( mono_val, mono_lev )
+  else
+     call DclSetParm('ENABLE_SOFTFILL',.true.)
+!     call DclClearShadeLevel
+!     call DclSetShadeLevel( shade_min, shade_max,   &
+! &                          (shade_max-shade_min)/s_num )
+  end if
+
   if(present(nongrid))then
      if(nongrid(1:1)=='o')then
         call DclSetXGrid( x )
@@ -107,7 +158,12 @@ subroutine Dcl_2D_cont_shade( outname,  &
      end if
   end if
 
-  call DclShadeContourEx( shade )
+  if(monoto==.true.)then
+     call DclShadeContour( shade )
+  else
+     call DclShadeContourEx( shade )
+  end if
+
   CALL UZLSET( 'LABELYL', .TRUE. )
   CALL UZLSET( 'LABELYR', .FALSE. )
   call DclDrawScaledAxis
@@ -116,11 +172,7 @@ subroutine Dcl_2D_cont_shade( outname,  &
   call DclDrawTitle( 't', outname, 0.0, 2 )
 
   call DclSetContourLabelFormat(form_typec)
-  if(present(cont_num))then
-     call DclSetContourLevel( cont_min, cont_max, (cont_max-cont_min)/cont_num )
-  else
-     call DclSetContourLevel( cont_min, cont_max, (cont_max-cont_min)/10 )
-  end if
+  call DclSetContourLevel( cont_min, cont_max, (cont_max-cont_min)/c_num )
   call DclDrawContour( contour )
 
   if(present(xg))then
@@ -130,11 +182,7 @@ subroutine Dcl_2D_cont_shade( outname,  &
   end if
 
 
-  if(present(color_num))then
-     call tone_bar( color_num, shade_min, shade_max, vx_max+0.05, 0.875, vy_min, vy_max, form_types )
-  else
-     call tone_bar( 56, shade_min, shade_max, vx_max+0.05, 0.875, vy_min, vy_max, form_types )
-  end if
+  call tone_bar( s_num, shade_min, shade_max, vx_max+0.05, 0.875, vy_min, vy_max, form_types, mono_log=monoto )
 
 end subroutine
 
@@ -144,9 +192,11 @@ subroutine Dcl_2D_cont_shade_MapPro( map_pro, outname,  &
   &  x, y, contour, shade, cont_min, cont_max,  &
   &  shade_min, shade_max, x_title, y_title, form_typec,  &
   &  form_types, viewx_min, viewx_max, viewy_min,  &
-  &  viewy_max, color_num, cont_num, nongrid )
+  &  viewy_max, color_num, cont_num, nongrid,  &
+  &  xg, yg, mono, mono_val, mono_lev )
   ! 2  2 ѿȥ顼ɤ褹.
   !  map_pro Ͽֹ, Ͽƥ⡼ɤڤؤ.
+  ! , xg, yg ץϿƤδط, ǽƤʤ.
   use dcl
   implicit none
   integer, intent(in) :: map_pro  ! DCL ϿѴؿֹ
@@ -161,8 +211,8 @@ subroutine Dcl_2D_cont_shade_MapPro( map_pro, outname,  &
   real, intent(in) :: shade_max  ! ɤ
   character(*), intent(in) :: x_title  ! x Υȥ
   character(*), intent(in) :: y_title  ! y Υȥ
-  character(6), intent(in), optional :: form_typec  ! contour ѤΥեޥå
-  character(6), intent(in), optional :: form_types  ! shade ѤΥեޥå
+  character(6), intent(in) :: form_typec  ! contour ѤΥեޥå
+  character(6), intent(in) :: form_types  ! shade ѤΥեޥå
   real, intent(in), optional :: viewx_min  ! ӥ塼ݡȤ x κǾ
   real, intent(in), optional :: viewx_max  ! ӥ塼ݡȤ x κ
   real, intent(in), optional :: viewy_min  ! ӥ塼ݡȤ y κǾ
@@ -174,15 +224,31 @@ subroutine Dcl_2D_cont_shade_MapPro( map_pro, outname,  &
                                         ! 1 ʸܤ, 2 ʸܤļ.
                                         ! o = ֳ, x = ֳ.
                                         ! ǥեȤǤ 'xx'.
+  real, intent(in), optional :: xg(:,:)  ! x 륰åκɸ
+  real, intent(in), optional :: yg(:,:)  ! y 륰åκɸ
+                    ! Ǥΰ֥ǡ, ʣ,
+                    ! Ǥ 2 İʾˤ.
+                    ! ǡľǤϤʤ, åɤ
+                    ! Ȥǽ.
+                    ! 3 ܤ, xg(:,1)  yg(:,1)  1 ܤ
+                    ! ɽ褦˻ꤹ뤳.
+  logical, intent(in), optional :: mono  ! ΥȡγĴˤ [.true.]
+                                         ! ǥեȤ .false.
+  real, intent(in), optional :: mono_val(:)  ! Ĵζ.
+                    ! mono=.true. ΤȤɬꤷʤȥ顼֤.
+                    ! ͤ mono_lev + 1 ʬ¸ߤʤФʤʤ.
+  integer, intent(in), optional :: mono_lev(:)  ! ȡޥåֹ. dcl  3 
+                    ! mono=.true. ΤȤꤷʤȥ顼֤.
   real, parameter :: pi=3.14159265
   real, parameter :: radius=6.38e6
   integer :: i, j, k  ! ź
-  integer :: nx, ny
+  integer :: nx, ny, s_num, c_num
   real :: uratio
   real :: vx_min, vx_max, vy_min, vy_max
   real :: undef, RMISS
   real :: map_lat_min, map_lat_max, map_lon_min, map_lon_max
   real :: mlat2dis_min, mlat2dis_max
+  logical :: monoto
 
   nx=size(x)
   ny=size(y)
@@ -246,6 +312,39 @@ subroutine Dcl_2D_cont_shade_MapPro( map_pro, outname,  &
      vy_max=0.5*(1.0+uratio*(vx_max-vx_min))
      vy_min=0.5*(1.0-uratio*(vx_max-vx_min))
   end if
+
+  if(present(color_num))then
+     s_num=color_num
+  else
+     s_num=56
+  end if
+
+  if(present(cont_num))then
+     c_num=cont_num
+  else
+     c_num=10
+  end if
+
+  if(present(mono))then
+     if(present(mono_val).and.present(mono_lev))then
+        if(size(mono_val)-1==size(mono_lev))then
+           monoto=mono
+        else
+           write(*,*) "*** ERROR ***"
+           write(*,*) "[array number] : mono_val = mono_lev + 1"
+           write(*,*) "STOP"
+           stop
+        end if
+     else
+        write(*,*) "*** ERROR ***"
+        write(*,*) "When option MONO is true, MONO_VAL and MONO_LEV must be specified."
+        write(*,*) "STOP"
+        stop
+     end if
+  else
+     monoto=.false.
+  end if
+
 !-- ޤ ---
 
   call undef_CReSS2Dcl( nx, ny, 1, contour)
@@ -265,6 +364,17 @@ subroutine Dcl_2D_cont_shade_MapPro( map_pro, outname,  &
   call DclFitMapParm
   call DclSetTransFunction
 
+  if(monoto==.true.)then
+     call DclSetParm('ENABLE_SOFTFILL',.true.)
+     call DclClearShadeLevel
+     call DclSetShadeLevel( mono_val, mono_lev )
+  else
+     call DclSetParm('ENABLE_SOFTFILL',.false.)
+!     call DclClearShadeLevel
+!     call DclSetShadeLevel( shade_min, shade_max,   &
+! &                          (shade_max-shade_min)/s_num )
+  end if
+
   call DclSetParm( 'GRAPH:LCLIP', .true. )
 !     call DclDrawViewPortFrame( 1 )
   if(present(nongrid))then
@@ -276,7 +386,12 @@ subroutine Dcl_2D_cont_shade_MapPro( map_pro, outname,  &
      end if
   end if
 
-  call DclShadeContourEx( shade )
+  if(monoto==.true.)then
+     call DclShadeContour( shade )
+  else
+     call DclShadeContourEx( shade )
+  end if
+
   CALL UZLSET( 'LABELYL', .TRUE. )
   CALL UZLSET( 'LABELYR', .FALSE. )
   call DclDrawAxis( 'bt', 1.0, 0.5 )
@@ -289,18 +404,10 @@ subroutine Dcl_2D_cont_shade_MapPro( map_pro, outname,  &
   call DclDrawGlobe()
 
   call DclSetContourLabelFormat(form_typec)
-  if(present(cont_num))then
-     call DclSetContourLevel( cont_min, cont_max, (cont_max-cont_min)/cont_num )
-  else
-     call DclSetContourLevel( cont_min, cont_max, (cont_max-cont_min)/10 )
-  end if
+  call DclSetContourLevel( cont_min, cont_max, (cont_max-cont_min)/c_num )
   call DclDrawContour( contour )
 
-  if(present(color_num))then
-     call tone_bar( color_num, shade_min, shade_max, vx_max+0.05, 0.875, vy_min, vy_max, form_types )
-  else
-     call tone_bar( 56, shade_min, shade_max, vx_max+0.05, 0.875, vy_min, vy_max, form_types )
-  end if
+  call tone_bar( s_num, shade_min, shade_max, vx_max+0.05, 0.875, vy_min, vy_max, form_types, mono_log=monoto )
 
 end subroutine
 
@@ -310,7 +417,8 @@ subroutine Dcl_2D_cont_shade_calendar( outname,  &
   &  x, y, contour, shade, cont_min, cont_max,  &
   &  shade_min, shade_max, x_title, y_title, date, days,  &
   &  form_typec, form_types, viewx_min, viewx_max,  &
-  &  viewy_min, viewy_max, color_num, cont_num, nongrid )
+  &  viewy_min, viewy_max, color_num, cont_num, nongrid,  &
+  &  xg, yg, mono, mono_val, mono_lev )
   ! 2  2 ѿȥ顼ɤ褹. calender б
   use dcl
   implicit none
@@ -327,8 +435,8 @@ subroutine Dcl_2D_cont_shade_calendar( outname,  &
   character(*), intent(in) :: y_title  ! y Υȥ
   type(dcl_date), intent(in) :: date  !  [yyyy:mm:dd]
   integer, intent(in) :: days  !  [day]
-  character(6), intent(in), optional :: form_typec  ! contour ѤΥեޥå
-  character(6), intent(in), optional :: form_types  ! shade ѤΥեޥå
+  character(6), intent(in) :: form_typec  ! contour ѤΥեޥå
+  character(6), intent(in) :: form_types  ! shade ѤΥեޥå
   real, intent(in), optional :: viewx_min  ! ӥ塼ݡȤ x κǾ
   real, intent(in), optional :: viewx_max  ! ӥ塼ݡȤ x κ
   real, intent(in), optional :: viewy_min  ! ӥ塼ݡȤ y κǾ
@@ -340,10 +448,26 @@ subroutine Dcl_2D_cont_shade_calendar( outname,  &
                                         ! 1 ʸܤ, 2 ʸܤļ.
                                         ! o = ֳ, x = ֳ.
                                         ! ǥեȤǤ 'xx'.
+  real, intent(in), optional :: xg(:,:)  ! x 륰åκɸ
+  real, intent(in), optional :: yg(:,:)  ! y 륰åκɸ
+                    ! Ǥΰ֥ǡ, ʣ,
+                    ! Ǥ 2 İʾˤ.
+                    ! ǡľǤϤʤ, åɤ
+                    ! Ȥǽ.
+                    ! 3 ܤ, xg(:,1)  yg(:,1)  1 ܤ
+                    ! ɽ褦˻ꤹ뤳.
+  logical, intent(in), optional :: mono  ! ΥȡγĴˤ [.true.]
+                                         ! ǥեȤ .false.
+  real, intent(in), optional :: mono_val(:)  ! Ĵζ.
+                    ! mono=.true. ΤȤɬꤷʤȥ顼֤.
+                    ! ͤ mono_lev + 1 ʬ¸ߤʤФʤʤ.
+  integer, intent(in), optional :: mono_lev(:)  ! ȡޥåֹ. dcl  3 
+                    ! mono=.true. ΤȤꤷʤȥ顼֤.
   integer :: i, j, k  ! ź
-  integer :: nx, ny
+  integer :: nx, ny, s_num, c_num
   real :: vx_min, vx_max, vy_min, vy_max
   real :: undef, RMISS
+  logical :: monoto
 
   nx=size(x)
   ny=size(y)
@@ -375,6 +499,37 @@ subroutine Dcl_2D_cont_shade_calendar( outname,  &
   else
      vy_max=0.8
   end if
+  if(present(color_num))then
+     s_num=color_num
+  else
+     s_num=56
+  end if
+
+  if(present(cont_num))then
+     c_num=cont_num
+  else
+     c_num=10
+  end if
+
+  if(present(mono))then
+     if(present(mono_val).and.present(mono_lev))then
+        if(size(mono_val)-1==size(mono_lev))then
+           monoto=mono
+        else
+           write(*,*) "*** ERROR ***"
+           write(*,*) "[array number] : mono_val = mono_lev + 1"
+           write(*,*) "STOP"
+           stop
+        end if
+     else
+        write(*,*) "*** ERROR ***"
+        write(*,*) "When option MONO is true, MONO_VAL and MONO_LEV must be specified."
+        write(*,*) "STOP"
+        stop
+     end if
+  else
+     monoto=.false.
+  end if
 
 !-- ޤ ---
 
@@ -386,9 +541,27 @@ subroutine Dcl_2D_cont_shade_calendar( outname,  &
 
   call DclNewFrame
   call DclSetWindow( 0.0, real(days), y(1), y(ny) )
+
+  if(present(xg))then
+     do i=1,size(xg,2)
+        call DclScalingPoint( xg(:,i), yg(:,i) )
+     end do
+  end if
+
   call DclSetViewPort( vx_min, vx_max, vy_min, vy_max )
   call DclSetTransFunction
 
+  if(monoto==.true.)then
+     call DclSetParm('ENABLE_SOFTFILL',.true.)
+     call DclClearShadeLevel
+     call DclSetShadeLevel( mono_val, mono_lev )
+  else
+     call DclSetParm('ENABLE_SOFTFILL',.false.)
+!     call DclClearShadeLevel
+!     call DclSetShadeLevel( shade_min, shade_max,   &
+! &                          (shade_max-shade_min)/s_num )
+  end if
+
   if(present(nongrid))then
      if(nongrid(1:1)=='o')then
         call DclSetXGrid( x )
@@ -398,7 +571,12 @@ subroutine Dcl_2D_cont_shade_calendar( outname,  &
      end if
   end if
 
-  call DclShadeContourEx( shade )
+  if(monoto==.true.)then
+     call DclShadeContour( shade )
+  else
+     call DclShadeContourEx( shade )
+  end if
+
   CALL UZLSET( 'LABELYL', .TRUE. )
   CALL UZLSET( 'LABELYR', .FALSE. )
   call DclDrawAxisCalendar( 'bt', date, nd=days )
@@ -407,19 +585,17 @@ subroutine Dcl_2D_cont_shade_calendar( outname,  &
   call DclDrawTitle( 't', outname, 0.0, 2 )
 
   call DclSetContourLabelFormat(form_typec)
-  if(present(cont_num))then
-     call DclSetContourLevel( cont_min, cont_max, (cont_max-cont_min)/cont_num )
-  else
-     call DclSetContourLevel( cont_min, cont_max, (cont_max-cont_min)/10 )
-  end if
+  call DclSetContourLevel( cont_min, cont_max, (cont_max-cont_min)/c_num )
   call DclDrawContour( contour )
 
-  if(present(color_num))then
-     call tone_bar( color_num, shade_min, shade_max, vx_max+0.05, 0.875, vy_min, vy_max, form_types )
-  else
-     call tone_bar( 56, shade_min, shade_max, vx_max+0.05, 0.875, vy_min, vy_max, form_types )
+  if(present(xg))then
+     do i=1,size(xg,2)
+        call DclDrawLine( xg(:,i), yg(:,i) )
+     end do
   end if
 
+  call tone_bar( s_num, shade_min, shade_max, vx_max+0.05, 0.875, vy_min, vy_max, form_types, mono_log=monoto )
+
 end subroutine
 
 !---------------------------------------------------------
@@ -428,7 +604,8 @@ subroutine Dcl_2D_cont_shade_vec( outname,  &
   &  x, y, contour, shade, vecx, vecy, vnx, vny, cont_min, cont_max,  &
   &  shade_min, shade_max, x_title, y_title,  &
   &  form_typec, form_types, viewx_min, viewx_max,  &
-  &  viewy_min, viewy_max, color_num, cont_num, nongrid )
+  &  viewy_min, viewy_max, color_num, cont_num, nongrid,  &
+  &  xg, yg, mono, mono_val, mono_lev )
   ! 2  3 ѿ, 顼, ٥ȥ褹.
   !  4 ѿƱ褬ǽȤʤ.
   ! Ū˱˥顼СĤΤ, ˥åȥ٥ȥ
@@ -450,8 +627,8 @@ subroutine Dcl_2D_cont_shade_vec( outname,  &
   real, intent(in) :: shade_max  ! ɤ
   character(*), intent(in) :: x_title  ! x Υȥ
   character(*), intent(in) :: y_title  ! y Υȥ
-  character(6), intent(in), optional :: form_typec  ! contour ѤΥեޥå
-  character(6), intent(in), optional :: form_types  ! shade ѤΥեޥå
+  character(6), intent(in) :: form_typec  ! contour ѤΥեޥå
+  character(6), intent(in) :: form_types  ! shade ѤΥեޥå
   real, intent(in), optional :: viewx_min  ! ӥ塼ݡȤ x κǾ
   real, intent(in), optional :: viewx_max  ! ӥ塼ݡȤ x κ
   real, intent(in), optional :: viewy_min  ! ӥ塼ݡȤ y κǾ
@@ -463,13 +640,29 @@ subroutine Dcl_2D_cont_shade_vec( outname,  &
                                         ! 1 ʸܤ, 2 ʸܤļ.
                                         ! o = ֳ, x = ֳ.
                                         ! ǥեȤǤ 'xx'.
+  real, intent(in), optional :: xg(:,:)  ! x 륰åκɸ
+  real, intent(in), optional :: yg(:,:)  ! y 륰åκɸ
+                    ! Ǥΰ֥ǡ, ʣ,
+                    ! Ǥ 2 İʾˤ.
+                    ! ǡľǤϤʤ, åɤ
+                    ! Ȥǽ.
+                    ! 3 ܤ, xg(:,1)  yg(:,1)  1 ܤ
+                    ! ɽ褦˻ꤹ뤳.
+  logical, intent(in), optional :: mono  ! ΥȡγĴˤ [.true.]
+                                         ! ǥեȤ .false.
+  real, intent(in), optional :: mono_val(:)  ! Ĵζ.
+                    ! mono=.true. ΤȤɬꤷʤȥ顼֤.
+                    ! ͤ mono_lev + 1 ʬ¸ߤʤФʤʤ.
+  integer, intent(in), optional :: mono_lev(:)  ! ȡޥåֹ. dcl  3 
+                    ! mono=.true. ΤȤꤷʤȥ顼֤.
   integer :: i, j, k  ! ź
-  integer :: nx, ny
+  integer :: nx, ny, s_num, c_num
   real :: factx, facty
   real, dimension(vnx,vny) :: um, vm  ! ٥ȥְͤ
   real :: vx_min, vx_max, vy_min, vy_max
   real :: undef, RMISS
   intrinsic :: nint
+  logical :: monoto
 
   nx=size(x)
   ny=size(y)
@@ -547,6 +740,38 @@ subroutine Dcl_2D_cont_shade_vec( outname,  &
      end do
   end do
 
+  if(present(color_num))then
+     s_num=color_num
+  else
+     s_num=56
+  end if
+
+  if(present(cont_num))then
+     c_num=cont_num
+  else
+     c_num=10
+  end if
+
+  if(present(mono))then
+     if(present(mono_val).and.present(mono_lev))then
+        if(size(mono_val)-1==size(mono_lev))then
+           monoto=mono
+        else
+           write(*,*) "*** ERROR ***"
+           write(*,*) "[array number] : mono_val = mono_lev + 1"
+           write(*,*) "STOP"
+           stop
+        end if
+     else
+        write(*,*) "*** ERROR ***"
+        write(*,*) "When option MONO is true, MONO_VAL and MONO_LEV must be specified."
+        write(*,*) "STOP"
+        stop
+     end if
+  else
+     monoto=.false.
+  end if
+
 !-- ޤ ---
 
   call undef_CReSS2Dcl( nx, ny, 1, contour)
@@ -557,9 +782,27 @@ subroutine Dcl_2D_cont_shade_vec( outname,  &
 
   call DclNewFrame
   call DclSetWindow( x(1), x(nx), y(1), y(ny) )
+
+  if(present(xg))then
+     do i=1,size(xg,2)
+        call DclScalingPoint( xg(:,i), yg(:,i) )
+     end do
+  end if
+
   call DclSetViewPort( vx_min, vx_max, vy_min, vy_max )
   call DclSetTransFunction
 
+  if(monoto==.true.)then
+     call DclSetParm('ENABLE_SOFTFILL',.true.)
+     call DclClearShadeLevel
+     call DclSetShadeLevel( mono_val, mono_lev )
+  else
+     call DclSetParm('ENABLE_SOFTFILL',.false.)
+!     call DclClearShadeLevel
+!     call DclSetShadeLevel( shade_min, shade_max,   &
+! &                          (shade_max-shade_min)/s_num )
+  end if
+
   if(present(nongrid))then
      if(nongrid(1:1)=='o')then
         call DclSetXGrid( x )
@@ -569,7 +812,12 @@ subroutine Dcl_2D_cont_shade_vec( outname,  &
      end if
   end if
 
-  call DclShadeContourEx( shade )
+  if(monoto==.true.)then
+     call DclShadeContour( shade )
+  else
+     call DclShadeContourEx( shade )
+  end if
+
   CALL UZLSET( 'LABELYL', .TRUE. )
   CALL UZLSET( 'LABELYR', .FALSE. )
   call DclDrawScaledAxis
@@ -578,21 +826,19 @@ subroutine Dcl_2D_cont_shade_vec( outname,  &
   call DclDrawTitle( 't', outname, 0.0, 2 )
 
   call DclSetContourLabelFormat(form_typec)
-  if(present(cont_num))then
-     call DclSetContourLevel( cont_min, cont_max, (cont_max-cont_min)/cont_num )
-  else
-     call DclSetContourLevel( cont_min, cont_max, (cont_max-cont_min)/10 )
-  end if
+  call DclSetContourLevel( cont_min, cont_max, (cont_max-cont_min)/c_num )
   call DclDrawContour( contour )
 
   call DclDrawVectors( um, vm )
 
-  if(present(color_num))then
-     call tone_bar( color_num, shade_min, shade_max, vx_max+0.05, 0.875, vy_min, vy_max, form_types )
-  else
-     call tone_bar( 56, shade_min, shade_max, vx_max+0.05, 0.875, vy_min, vy_max, form_types )
+  if(present(xg))then
+     do i=1,size(xg,2)
+        call DclDrawLine( xg(:,i), yg(:,i) )
+     end do
   end if
 
+  call tone_bar( s_num, shade_min, shade_max, vx_max+0.05, 0.875, vy_min, vy_max, form_types, mono_log=monoto )
+
 end subroutine
 
 !---------------------------------------------------------
@@ -601,7 +847,8 @@ subroutine Dcl_2D_cont_shade_vec_calendar( outname,  &
   &  x, y, contour, shade, vecx, vecy, vnx, vny, cont_min, cont_max,  &
   &  shade_min, shade_max, x_title, y_title, date, days,  &
   &  form_typec, form_types, viewx_min, viewx_max,  &
-  &  viewy_min, viewy_max, color_num, cont_num, nongrid )
+  &  viewy_min, viewy_max, color_num, cont_num, nongrid,  &
+  &  xg, yg, mono, mono_val, mono_lev )
   ! 2  3 ѿ, 顼, ٥ȥ褹.
   !  4 ѿƱ褬ǽȤʤ.
   ! Ū˱˥顼СĤΤ, ˥åȥ٥ȥ
@@ -625,8 +872,8 @@ subroutine Dcl_2D_cont_shade_vec_calendar( outname,  &
   character(*), intent(in) :: y_title  ! y Υȥ
   type(dcl_date), intent(in) :: date  !  [yyyy:mm:dd]
   integer, intent(in) :: days  !  [day]
-  character(6), intent(in), optional :: form_typec  ! contour ѤΥեޥå
-  character(6), intent(in), optional :: form_types  ! shade ѤΥեޥå
+  character(6), intent(in) :: form_typec  ! contour ѤΥեޥå
+  character(6), intent(in) :: form_types  ! shade ѤΥեޥå
   real, intent(in), optional :: viewx_min  ! ӥ塼ݡȤ x κǾ
   real, intent(in), optional :: viewx_max  ! ӥ塼ݡȤ x κ
   real, intent(in), optional :: viewy_min  ! ӥ塼ݡȤ y κǾ
@@ -638,12 +885,28 @@ subroutine Dcl_2D_cont_shade_vec_calendar( outname,  &
                                         ! 1 ʸܤ, 2 ʸܤļ.
                                         ! o = ֳ, x = ֳ.
                                         ! ǥեȤǤ 'xx'.
+  real, intent(in), optional :: xg(:,:)  ! x 륰åκɸ
+  real, intent(in), optional :: yg(:,:)  ! y 륰åκɸ
+                    ! Ǥΰ֥ǡ, ʣ,
+                    ! Ǥ 2 İʾˤ.
+                    ! ǡľǤϤʤ, åɤ
+                    ! Ȥǽ.
+                    ! 3 ܤ, xg(:,1)  yg(:,1)  1 ܤ
+                    ! ɽ褦˻ꤹ뤳.
+  logical, intent(in), optional :: mono  ! ΥȡγĴˤ [.true.]
+                                         ! ǥեȤ .false.
+  real, intent(in), optional :: mono_val(:)  ! Ĵζ.
+                    ! mono=.true. ΤȤɬꤷʤȥ顼֤.
+                    ! ͤ mono_lev + 1 ʬ¸ߤʤФʤʤ.
+  integer, intent(in), optional :: mono_lev(:)  ! ȡޥåֹ. dcl  3 
+                    ! mono=.true. ΤȤꤷʤȥ顼֤.
   integer :: i, j, k  ! ź
-  integer :: nx, ny
+  integer :: nx, ny, s_num, c_num
   real :: factx, facty
   real, dimension(vnx,vny) :: um, vm  ! ٥ȥְͤ
   real :: vx_min, vx_max, vy_min, vy_max
   real :: undef, RMISS
+  logical :: monoto
 
   nx=size(x)
   ny=size(y)
@@ -724,6 +987,38 @@ subroutine Dcl_2D_cont_shade_vec_calendar( outname,  &
      end do
   end do
 
+  if(present(color_num))then
+     s_num=color_num
+  else
+     s_num=56
+  end if
+
+  if(present(cont_num))then
+     c_num=cont_num
+  else
+     c_num=10
+  end if
+
+  if(present(mono))then
+     if(present(mono_val).and.present(mono_lev))then
+        if(size(mono_val)-1==size(mono_lev))then
+           monoto=mono
+        else
+           write(*,*) "*** ERROR ***"
+           write(*,*) "[array number] : mono_val = mono_lev + 1"
+           write(*,*) "STOP"
+           stop
+        end if
+     else
+        write(*,*) "*** ERROR ***"
+        write(*,*) "When option MONO is true, MONO_VAL and MONO_LEV must be specified."
+        write(*,*) "STOP"
+        stop
+     end if
+  else
+     monoto=.false.
+  end if
+
 !-- ޤ ---
 
   call undef_CReSS2Dcl( nx, ny, 1, contour)
@@ -734,9 +1029,27 @@ subroutine Dcl_2D_cont_shade_vec_calendar( outname,  &
 
   call DclNewFrame
   call DclSetWindow( 0.0, real(days), y(1), y(ny) )
+
+  if(present(xg))then
+     do i=1,size(xg,2)
+        call DclScalingPoint( xg(:,i), yg(:,i) )
+     end do
+  end if
+
   call DclSetViewPort( vx_min, vx_max, vy_min, vy_max )
   call DclSetTransFunction
 
+  if(monoto==.true.)then
+     call DclSetParm('ENABLE_SOFTFILL',.true.)
+     call DclClearShadeLevel
+     call DclSetShadeLevel( mono_val, mono_lev )
+  else
+     call DclSetParm('ENABLE_SOFTFILL',.false.)
+!     call DclClearShadeLevel
+!     call DclSetShadeLevel( shade_min, shade_max,   &
+! &                          (shade_max-shade_min)/s_num )
+  end if
+
   if(present(nongrid))then
      if(nongrid(1:1)=='o')then
         call DclSetXGrid( x )
@@ -746,7 +1059,12 @@ subroutine Dcl_2D_cont_shade_vec_calendar( outname,  &
      end if
   end if
 
-  call DclShadeContourEx( shade )
+  if(monoto==.true.)then
+     call DclShadeContour( shade )
+  else
+     call DclShadeContourEx( shade )
+  end if
+
   CALL UZLSET( 'LABELYL', .TRUE. )
   CALL UZLSET( 'LABELYR', .FALSE. )
   call DclDrawAxisCalendar( 'bt', date, nd=days )
@@ -755,21 +1073,19 @@ subroutine Dcl_2D_cont_shade_vec_calendar( outname,  &
   call DclDrawTitle( 't', outname, 0.0, 2 )
 
   call DclSetContourLabelFormat(form_typec)
-  if(present(cont_num))then
-     call DclSetContourLevel( cont_min, cont_max, (cont_max-cont_min)/cont_num )
-  else
-     call DclSetContourLevel( cont_min, cont_max, (cont_max-cont_min)/10 )
-  end if
+  call DclSetContourLevel( cont_min, cont_max, (cont_max-cont_min)/c_num )
   call DclDrawContour( contour )
 
   call DclDrawVectors( um, vm )
 
-  if(present(color_num))then
-     call tone_bar( color_num, shade_min, shade_max, vx_max+0.05, 0.875, vy_min, vy_max, form_types )
-  else
-     call tone_bar( 56, shade_min, shade_max, vx_max+0.05, 0.875, vy_min, vy_max, form_types )
+  if(present(xg))then
+     do i=1,size(xg,2)
+        call DclDrawLine( xg(:,i), yg(:,i) )
+     end do
   end if
 
+  call tone_bar( s_num, shade_min, shade_max, vx_max+0.05, 0.875, vy_min, vy_max, form_types, mono_log=monoto )
+
 end subroutine
 
 !---------------------------------------------------------
@@ -1250,7 +1566,7 @@ end subroutine
 
 !---------------------------------------------------------
 
-subroutine tone_bar( color_num, shade_min, shade_max, vx_min, vx_max, vy_min, vy_max, form_types )  ! ˥ȡСư
+subroutine tone_bar( color_num, shade_min, shade_max, vx_min, vx_max, vy_min, vy_max, form_types, mono_log )  ! ˥ȡСư
   use dcl
   implicit none
   integer, intent(in) :: color_num  ! Ѥ뿧ο
@@ -1261,10 +1577,21 @@ subroutine tone_bar( color_num, shade_min, shade_max, vx_min, vx_max, vy_min, vy
   real, intent(in) :: vy_min  ! ӥ塼ݡȤ y κǾ
   real, intent(in) :: vy_max  ! ӥ塼ݡȤ y κ
   character(6), intent(in) :: form_types  ! ٥եޥå
+  logical, intent(in), optional :: mono_log
   integer :: k
   real :: pi(2,color_num+1)
   real :: dp
   real :: coldim1(color_num+1), coldim2(color_num/2+1)
+  logical :: monoto  ! Υȡν
+
+!-- ץν
+  if(present(mono_log))then
+     monoto=mono_log
+  else
+     monoto=.false.
+  end if
+
+!-- ޤ
 
   call GRFIG
   call DclSetWindow( 0.0, 1.0, shade_min, shade_max )
@@ -1290,7 +1617,15 @@ subroutine tone_bar( color_num, shade_min, shade_max, vx_min, vx_max, vy_min, vy
 
   call DclSetXGrid( (/0.0,1.0/) )
   call DclSetYGrid( PI(1,:) )
-  call DclShadeContourEx( PI )
+
+  if(monoto==.true.)then
+     call DclSetParm('ENABLE_SOFTFILL',.true.)
+     call DclShadeContour( PI )
+  else
+     call DclSetParm('ENABLE_SOFTFILL',.false.)
+     call DclShadeContourEx( PI )
+  end if
+
   CALL SLPVPR( 3 )
   CALL UZLSET( 'LABELYR', .TRUE. )
   CALL UZLSET( 'LABELYL', .FALSE. )
@@ -1341,7 +1676,9 @@ end subroutine
 !--------------------------------------------------------
 
 subroutine color_setting( color_num, val_min, val_max, col_tab,   &
-  &                       col_max, col_min, col_bg )  ! 顼ޥåפοȿͤб뼫ư롼
+  &                       col_max, col_min, col_bg, reverse,  &
+  &                       min_tab, max_tab )
+  ! 顼ޥåפοȿͤб뼫ư롼
   use dcl
   implicit none
   integer, intent(in) :: color_num  ! Ѥ륫顼μ
@@ -1353,10 +1690,20 @@ subroutine color_setting( color_num, val_min, val_max, col_tab,   &
   logical, intent(in), optional :: col_bg  ! طʿؤ ǥեȤʤ.
   integer :: map_num  ! 顼ޥåפΥޥåֹ (optional °Ĥ뤳)
   integer :: i, j, k  ! ź
+  logical, intent(in), optional :: reverse  ! 顼ֹȿž.
+  integer, intent(in), optional :: min_tab  ! val_min ʲͤб륫顼ֹ, ǥեȤϹ
+  integer, intent(in), optional :: max_tab  ! val_max ʾͤб륫顼ֹ, ǥեȤϹ
   integer :: ipat
   real :: dv  ! 顼ޥåפбͤ
   integer :: cmap_min, cmap_max
   real :: tlev1, tlev2
+  logical :: rev
+  real :: white_min, black_max, RMISS
+  integer :: white, black, ITON
+
+!-- Dcl ¦ undef ͥå
+   CALL GLRGET( 'RMISS', RMISS )
+   CALL GLLSET( 'LMISS', .TRUE. )
 
   if(present(col_tab))then
      map_num=col_tab
@@ -1380,19 +1727,143 @@ subroutine color_setting( color_num, val_min, val_max, col_tab,   &
      call SWpSET( 'LFGBG', col_bg )     
   end if
 
- write(*,*) "col_tab", map_num
+  if(present(reverse))then
+     rev=reverse
+  else
+     rev=.false.
+  end if
+
+  if(present(min_tab))then
+     white=min_tab
+  else
+     white=999
+  end if
+
+  if(present(max_tab))then
+     black=max_tab
+  else
+     black=1999
+  end if
 
   call sgscmn(map_num)
 
   call UEITLV
 
+!-- val_max ʾ black ɤ
+  TLEV1=RMISS
+  TLEV2=val_min
+  IPAT=white
+  CALL DclSetShadeLevel( TLEV1, TLEV2, IPAT )
+!  CALL UEQTLV( TLEV1, TLEV2, IPAT, color_num+2 )
+!  write(*,*) TLEV1, TLEV2, IPAT
+
   dv=(val_max-val_min)/color_num
-  do k=1,color_num
-     TLEV1=val_min+(k-1)*dv
-     TLEV2=TLEV1+dv
-     IPAT=(cmap_min+int((k-1)*(real(cmap_max)/real(color_num))))*1000+199
-     CALL UESTLV( TLEV1, TLEV2, IPAT )
-  end do
+
+  if(rev==.true.)then
+     do k=1,color_num
+        TLEV1=val_min+(k-1)*dv
+        TLEV2=TLEV1+dv
+        IPAT=(cmap_min+int((color_num-k)*(real(cmap_max-cmap_min)/real(color_num-1))))*1000+999
+        CALL DclSetShadeLevel( TLEV1, TLEV2, IPAT )
+!        CALL UEQTLV( TLEV1, TLEV2, IPAT, k )
+!        write(*,*) TLEV1, TLEV2, IPAT
+     end do
+  else
+     do k=1,color_num
+        TLEV1=val_min+(k-1)*dv
+        TLEV2=TLEV1+dv
+        IPAT=(cmap_min+int((k-1)*(real(cmap_max-cmap_min)/real(color_num-1))))*1000+999
+        CALL DclSetShadeLevel( TLEV1, TLEV2, IPAT )
+!        CALL UEQTLV( TLEV1, TLEV2, IPAT, k )
+!        write(*,*) TLEV1, TLEV2, IPAT
+     end do
+  end if
+
+  TLEV1=val_max
+  TLEV2=RMISS
+  IPAT=black
+  CALL DclSetShadeLevel( TLEV1, TLEV2, IPAT )
+!  CALL UEQTLV( TLEV1, TLEV2, IPAT, color_num+1 )
+  write(*,*) TLEV1, TLEV2, IPAT
+
+end subroutine
+
+!---------------------------------------------------
+
+subroutine monotone_setting( ton_tab, val_min, val_max, nega_ton_tab,  &
+  &                          full_tone )
+! color_setting ΥΥȡС
+! ȡơ֥ȴ 5 षʤΤ, val_min, val_max Ū 5 ʬ䤷, ȡƤϤ.
+! ޤ, nega_ton_tab ꤵƤ, 10 ʬ䤹.
+  use dcl
+  implicit none
+  integer, intent(in), optional :: ton_tab  ! dcl Υȡơ֥
+  real, intent(in) :: val_min  ! 顼κǾ
+  real, intent(in) :: val_max  ! 顼κ
+  integer, intent(in), optional :: nega_ton_tab  ! ȡơ֥ 2 ȤȤ, ͤξΰ˸äǻƤ˻. Υȡ 0 ǻƤ.
+  logical, intent(in), optional :: full_tone  ! 碌, ƥȡ 6 ʳΤ, val_min, val_max κŪ 6 ʬ䤷ƥȡƤ. , 򤹤, ȡζͤڤΤ褤ͤˤʤʤ. ͤ .true. ͭȤʤ.
+  integer :: map_num  ! 顼ޥåפΥޥåֹ (optional °Ĥ뤳)
+  integer :: i, j, k  ! ź
+  integer :: ipat, itvtone, tone_mapping
+  real :: dv  ! 顼ޥåפбͤ
+  integer :: cmap_min, cmap_max
+  real :: tlev1, tlev2
+
+  call UEITLV
+
+  if(present(nega_ton_tab))then
+     if(present(full_tone))then
+        if(full_tone==.true.)then
+           itvtone=12
+        else
+           itvtone=10
+        end if
+     else
+        itvtone=10
+     end if
+  else
+     if(present(full_tone))then
+        if(full_tone==.true.)then
+           itvtone=6
+        else
+           itvtone=5
+        end if
+     else
+        itvtone=5
+     end if
+  end if
+
+  dv=(val_max-val_min)/real(itvtone)
+
+  if(itvtone==10.or.itvtone==12)then
+     tone_mapping=itvtone/2
+  else
+     tone_mapping=itvtone
+  end if
+
+  if(itvtone==tone_mapping)then
+     do k=1,tone_mapping
+        TLEV1=val_min+(k-1)*dv
+        TLEV2=TLEV1+dv
+        IPAT=100*ton_tab+k
+        CALL UESTLV( TLEV1, TLEV2, IPAT )
+     end do
+  else
+     do k=1,tone_mapping
+        TLEV1=0.5*(val_max+val_min)+(k-1)*dv
+        TLEV2=TLEV1+dv
+        IPAT=100*ton_tab+k
+        CALL UESTLV( TLEV1, TLEV2, IPAT )
+write(*,*) "tlev", tlev1, tlev2
+     end do
+     do k=1,tone_mapping
+        TLEV1=0.5*(val_max+val_min)-k*dv
+        TLEV2=TLEV1+dv
+        IPAT=100*nega_ton_tab+k
+        CALL UESTLV( TLEV1, TLEV2, IPAT )
+write(*,*) "bgtlev", tlev1, tlev2
+     end do
+  end if
 
 
 end subroutine
